==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/INSPECTIONASPECTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour INSPECTIONASPECTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="INSPECTIONASPECTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSPECTIONOBJECTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASPECTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INSPECTIONASPECTID_Type", propOrder = {
    "inspectionobjectid",
    "objtype",
    "aspectid"
})
public class INSPECTIONASPECTID_Type {

    @XmlElement(name = "INSPECTIONOBJECTID", required = true)
    protected OBJECT_Type inspectionobjectid;
    @XmlElement(name = "OBJTYPE", required = true)
    protected String objtype;
    @XmlElement(name = "ASPECTID", required = true)
    protected ASPECTID_Type aspectid;

    /**
     * Obtient la valeur de la propriété inspectionobjectid.
     * 
     * @return
     *     possible object is
     *     {@link OBJECT_Type }
     *     
     */
    public OBJECT_Type getINSPECTIONOBJECTID() {
        return inspectionobjectid;
    }

    /**
     * Définit la valeur de la propriété inspectionobjectid.
     * 
     * @param value
     *     allowed object is
     *     {@link OBJECT_Type }
     *     
     */
    public void setINSPECTIONOBJECTID(OBJECT_Type value) {
        this.inspectionobjectid = value;
    }

    /**
     * Obtient la valeur de la propriété objtype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBJTYPE() {
        return objtype;
    }

    /**
     * Définit la valeur de la propriété objtype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBJTYPE(String value) {
        this.objtype = value;
    }

    /**
     * Obtient la valeur de la propriété aspectid.
     * 
     * @return
     *     possible object is
     *     {@link ASPECTID_Type }
     *     
     */
    public ASPECTID_Type getASPECTID() {
        return aspectid;
    }

    /**
     * Définit la valeur de la propriété aspectid.
     * 
     * @param value
     *     allowed object is
     *     {@link ASPECTID_Type }
     *     
     */
    public void setASPECTID(ASPECTID_Type value) {
        this.aspectid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/INSPECTIONASPECTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INSPECTIONASPECTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="INSPECTIONASPECTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSPECTIONOBJECTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASPECTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INSPECTIONASPECTID_Type", propOrder = {
    "inspectionobjectid",
    "objtype",
    "aspectid"
})
public class INSPECTIONASPECTID_Type {

    @XmlElement(name = "INSPECTIONOBJECTID", required = true)
    protected OBJECT_Type inspectionobjectid;
    @XmlElement(name = "OBJTYPE", required = true)
    protected String objtype;
    @XmlElement(name = "ASPECTID", required = true)
    protected ASPECTID_Type aspectid;

    /**
     * Gets the value of the inspectionobjectid property.
     * 
     * @return
     *     possible object is
     *     {@link OBJECT_Type }
     *     
     */
    public OBJECT_Type getINSPECTIONOBJECTID() {
        return inspectionobjectid;
    }

    /**
     * Sets the value of the inspectionobjectid property.
     * 
     * @param value
     *     allowed object is
     *     {@link OBJECT_Type }
     *     
     */
    public void setINSPECTIONOBJECTID(OBJECT_Type value) {
        this.inspectionobjectid = value;
    }

    /**
     * Gets the value of the objtype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBJTYPE() {
        return objtype;
    }

    /**
     * Sets the value of the objtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBJTYPE(String value) {
        this.objtype = value;
    }

    /**
     * Gets the value of the aspectid property.
     * 
     * @return
     *     possible object is
     *     {@link ASPECTID_Type }
     *     
     */
    public ASPECTID_Type getASPECTID() {
        return aspectid;
    }

    /**
     * Sets the value of the aspectid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ASPECTID_Type }
     *     
     */
    public void setASPECTID(ASPECTID_Type value) {
        this.aspectid = value;
    }

}
